/*!
 * @file story_entity.h
  *  holds the base class of everything that is playable - that is part of the story
*/


#ifndef _STORY_ENTITY_H
#define _STORY_ENTITY_H

#include "base_object.h"
#include "story_def.h"
#include "error.h"

//! A class that represents something to play in orxonox. it is a container for worlds, movies, mission briefings, etc...
class StoryEntity : public BaseObject {

 public:
  StoryEntity ();
  virtual ~StoryEntity ();


  // INIT AND LOAD //
  virtual ErrorMessage preLoad() {};
  virtual ErrorMessage load() {};
  virtual ErrorMessage postLoad() {};
  virtual ErrorMessage check() {};

  // RUNNING //
  virtual ErrorMessage preStart() {};
  virtual ErrorMessage start() = 0;
  virtual ErrorMessage pause() = 0;
  virtual ErrorMessage rewind() {};
  virtual ErrorMessage suspend() {};
  virtual ErrorMessage resume() = 0;
  virtual ErrorMessage stop() = 0;
  virtual ErrorMessage destroy() {};

  void setStoryID(int storyID);
  int getStoryID();

  void setNextStoryID(int nextStoryID);
  int getNextStoryID();

  protected:
    bool isInit;         //!< if the entity is initialized, this has to be true.
    bool readyToRun;     //!< If the entity is ready to run -> post-check.
    bool isPaused;       //!< is true if the entity is paused
    bool isSuspended;    //!< if the Entity is suspended.

 private:
  int storyID;           //!< this is the number of this entity, identifying it in a list/tree...
  int nextStoryID;       //!< if this entity has finished, this entity shall be called
};

#endif /* _STORY_ENTITY_H */
